@@ -464,7 +464,7 @@ class XpraServer(gobject.GObject, X11ServerBase):
         with xsync:
             children = get_children(root)
         for window in children:
-            xid = window.get_xid()
+            xid = get_xwindow(window)
             can_add = False
             with xlog:
                 can_add = X11Window.is_override_redirect(xid) and X11Window.is_mapped(xid)
@@ -912,7 +912,9 @@ class XpraServer(gobject.GObject, X11ServerBase):
         if not window:
             windowlog("cannot map window %i: not found, already removed?", wid)
             return
-        assert not window.is_OR()
+        if window.is_OR():
+            windowlog.warn("Warning: received map event on OR window %s", wid)
+            return
         ss = self.get_server_source(proto)
         if ss is None:
             return
@@ -1044,7 +1046,7 @@ class XpraServer(gobject.GObject, X11ServerBase):
                         counter = max(0, resize_counter-1)
                         from xpra.server.source.windows_mixin import WindowsMixin
                         for s in self._server_sources.values():
-                            if s!=ss and isinstance(ss, WindowsMixin):
+                            if s!=ss and isinstance(s, WindowsMixin):
                                 s.resize_window(wid, window, aw, ah, resize_counter=counter)
                     damage |= owx!=ax or owy!=ay or resized
             if not shown and not skip_geometry:
