@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
 # Copyright (C) 2011 Serviware (Arthur Huillet, <ahuillet@serviware.com>)
-# Copyright (C) 2010-2019 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2010-2020 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-from xpra.util import csv, nonl, envbool
+from xpra.util import csv, nonl, envbool, repr_ellipsized
 from xpra.os_util import bytestostr
 from xpra.gtk_common.keymap import get_gtk_keymap
 from xpra.gtk_common.gtk_util import keymap_get_for_display, display_get_default, get_default_root_window
@@ -19,7 +19,7 @@ from xpra.x11.xkbhelper import (
     do_set_keymap, set_all_keycodes, set_keycode_translation,
     get_modifiers_from_meanings, get_modifiers_from_keycodes,
     clear_modifiers, set_modifiers, map_missing_modifiers,
-    clean_keyboard_state,
+    clean_keyboard_state, get_keycode_mappings,
     DEBUG_KEYSYMS,
     )
 from xpra.x11.bindings.keyboard_bindings import X11KeyboardBindings #@UnresolvedImport
@@ -404,7 +404,7 @@ class KeyboardConfig(KeyboardConfigBase):
         with xsync:
             clean_keyboard_state()
             #keycodes:
-            keycode_to_keynames = X11Keyboard.get_keycode_mappings()
+            keycode_to_keynames = get_keycode_mappings()
             self.keycode_translation = {}
             #prefer keycodes that don't use the lowest level+mode:
             default_for_keyname = {}
@@ -442,7 +442,7 @@ class KeyboardConfig(KeyboardConfigBase):
             self.update_keycode_mappings()
 
     def update_keycode_mappings(self):
-        self.keycode_mappings = X11Keyboard.get_keycode_mappings()
+        self.keycode_mappings = get_keycode_mappings()
 
 
     def do_get_keycode(self, client_keycode, keyname, pressed, modifiers, group):
@@ -503,8 +503,16 @@ class KeyboardConfig(KeyboardConfigBase):
         #first, try to honour shift state:
         shift = ("shift" in modifiers) ^ ("lock" in modifiers)
         mode = 0
+        numlock = 0
+        numlock_modifier = None
+        for mod, keynames in self.keynames_for_mod.items():
+            if "Num_Lock" in keynames:
+                numlock_modifier = mod
+                break
         for mod in modifiers:
             names = self.keynames_for_mod.get(mod, [])
+            if "Num_Lock" in names:
+                numlock = 1
             for name in names:
                 if name in ("ISO_Level3_Shift", "Mode_switch"):
                     mode = 1
@@ -547,7 +555,11 @@ class KeyboardConfig(KeyboardConfigBase):
                     else:
                         kmlog("adding '%s' to modifiers", mod)
                         modifiers.append(mod)
-                if (level & 1) ^ shift:
+                #keypad overrules shift state (see #2702):
+                if keyname.startswith("KP_"):
+                    if numlock_modifier and not numlock:
+                        toggle_modifier(numlock_modifier)
+                elif (level & 1) ^ shift:
                     #shift state does not match
                     toggle_modifier("shift")
                 if int(bool(level & 2)) ^ mode:
